@@ -37,6 +37,8 @@ CREATE TABLE "User" (
                      OR is_system_user )
 );
 
+CREATE INDEX "User_created_by_user_id" ON "User" ("created_by_user_id");
+
 CREATE TABLE "UserImage" (
        user_id                  INT8            PRIMARY KEY,
        mime_type                citext          NOT NULL,
@@ -121,6 +123,8 @@ CREATE TABLE "TimeZone" (
 --                  INITIALLY DEFERRED
 );
 
+CREATE INDEX "TimeZone_iso_code" ON "TimeZone" ("iso_code");
+
 CREATE TABLE "Role" (
        role_id                  SERIAL8         PRIMARY KEY,
        name                     citext          UNIQUE  NOT NULL
@@ -138,6 +142,9 @@ CREATE TABLE "UserWikiRole" (
        PRIMARY KEY ( user_id, wiki_id )
 );
 
+CREATE INDEX "UserWikiRole_wiki_id" ON "UserWikiRole" (wiki_id);
+CREATE INDEX "UserWikiRole_role_id" ON "UserWikiRole" (role_id);
+
 CREATE TABLE "WikiRolePermission" (
        wiki_id                  INT8            NOT NULL,
        role_id                  INT8            NOT NULL,
@@ -145,6 +152,9 @@ CREATE TABLE "WikiRolePermission" (
        PRIMARY KEY ( wiki_id, role_id, permission_id )
 );
 
+CREATE INDEX "WikiRolePermission_role_id" ON "WikiRolePermission" (role_id);
+CREATE INDEX "WikiRolePermission_permission_id" ON "WikiRolePermission" (permission_id);
+
 CREATE DOMAIN revision AS INT
        CONSTRAINT valid_revision CHECK ( VALUE > 0 );
 
@@ -347,6 +357,9 @@ CREATE TABLE "File" (
        CONSTRAINT valid_file_size CHECK ( file_size > 0 )
 );
 
+CREATE INDEX "File_user_id" ON "File" (user_id);
+CREATE INDEX "File_page_id" ON "File" (page_id);
+
 CREATE TABLE "SystemLog" (
        log_id             SERIAL8            PRIMARY KEY,
        user_id            INT8               NOT NULL,
@@ -357,6 +370,10 @@ CREATE TABLE "SystemLog" (
        data_blob          BYTEA              NULL
 );
 
+CREATE INDEX "SystemLog_user_id" ON "SystemLog" (user_id);
+CREATE INDEX "SystemLog_wiki_id" ON "SystemLog" (wiki_id);
+CREATE INDEX "SystemLog_page_id" ON "SystemLog" (page_id);
+
 CREATE TABLE "Process" (
        process_id         SERIAL8            PRIMARY KEY,
        system_pid         INT4               NULL,
@@ -369,6 +386,8 @@ CREATE TABLE "Process" (
        last_modified_datetime  TIMESTAMP WITHOUT TIME ZONE  NOT NULL DEFAULT CURRENT_TIMESTAMP
 );
 
+CREATE INDEX "Process_wiki_id" ON "Process" (wiki_id);
+
 CREATE TABLE "Session" (
        id                 CHAR(72)           PRIMARY KEY,
        session_data       BYTEA              NOT NULL,
@@ -527,4 +546,4 @@ ALTER TABLE "Process" ADD CONSTRAINT "Process_wiki_id"
   FOREIGN KEY ("wiki_id") REFERENCES "Wiki" ("wiki_id")
   ON DELETE SET NULL ON UPDATE CASCADE;
 
-INSERT INTO "Version" (version) VALUES (6);
+INSERT INTO "Version" (version) VALUES (7);
